//  
//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
//  Debugged and Featurized by Michael Hemy
//
//  This file may be distributed under terms of the GPL
//

#include "xosview.h"

main( int argc, char *argv[] )

{
  XOSView osview( argc, argv );

  osview.run();
}
