//  
//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
//  Debugged and Featurized by Michael Hemy
//
//  This file may be distributed under terms of the GPL
//

#ifndef _SWAPMETER_H_
#define _SWAPMETER_H_

#include "fieldmeter.h"
#include <fstream.h>

#define  MEMFILENAME "/proc/meminfo"


class SwapMeter : public FieldMeter {
public:
  SwapMeter( XOSView *parent, int x, int y, int width, int height );
  ~SwapMeter( void );

  const char *name( void ) { return "SwapMeter"; }  
  void checkevent( void );
protected:
  ifstream *meminfo_;
  long fpos_;

  void getswapinfo( void );
private:
};


#endif
