//  
//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
//  Debugged and Featurized by Michael Hemy
//
//  This file may be distributed under terms of the GPL
//

#ifndef _MEMMETER_H_
#define _MEMMETER_H_

#include "fieldmeter.h"
#include <fstream.h>

#define  MEMFILENAME "/proc/meminfo"


class MemMeter : public FieldMeter {
public:
  MemMeter( XOSView *parent, int x, int y, int width, int height );
  ~MemMeter( void );

  const char *name( void ) { return "MemMeter"; }  
  void checkevent( void );
protected:
  ifstream *meminfo_;
  long fpos_;

  void getmeminfo( void );
private:
};


#endif
