//  
//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
//  Debugged and Featurized by Michael Hemy
//
//  This file may be distributed under terms of the GPL
//

#ifndef _XOSVIEW_H_
#define _XOSVIEW_H_

#include "xwin.h"

class CPUMeter;
class MemMeter;
class SwapMeter;
class NetInMeter;
class NetOutMeter;

class XOSView : public XWin {
public:
  XOSView( int argc, char *argv[] );
  ~XOSView( void );

  void resize( void );
  void draw( void );
  void run( void );
  void keyrelease( char *ch );
  const char *winname( void );
  void visnotify( void );
protected:
  CPUMeter *cpu_;
  MemMeter *mem_;
  SwapMeter *swap_;
  NetInMeter *netin_;
  NetOutMeter *netout_;
  int done_, legend_, nummeters_;
  float netmax_;

  void parseargs( int argc, char *argv[] );
private:
};

#endif
